@@ -3,7 +3,7 @@
     zeronimo.messaging
     ~~~~~~~~~~~~~~~~~~
 
-    :copyright: (c) 2013 by Heungsub Lee
+    :copyright: (c) 2013-2014 by Heungsub Lee
     :license: BSD, see LICENSE for more details.
 """
 from __future__ import absolute_import
@@ -13,19 +13,20 @@ try:
 except ImportError:
     import pickle
 
-import msgpack
+import zmq
 
 from .helpers import make_repr
 
 
 __all__ = ['ACK', 'DONE', 'ITER', 'ACCEPT', 'REJECT', 'RETURN', 'RAISE',
-           'YIELD', 'BREAK', 'Call', 'Reply', 'send', 'recv']
+           'YIELD', 'BREAK', 'PACK', 'UNPACK', 'Call', 'Reply', 'send', 'recv']
 
 
-# masks
+# method masks
 ACK = 0b10000000
 DONE = 0b01000000
 ITER = 0b00100000
+
 # methods
 ACCEPT = ACK | 0b01
 REJECT = ACK | 0b10
@@ -35,7 +36,14 @@ YIELD = ITER | 0b01
 BREAK = ITER | 0b10
 
 
-_Call = namedtuple('_Call', ['function_name', 'args', 'kwargs', 'call_id',
+#: The default function to pack message.
+PACK = pickle.dumps
+
+#: The default function to unpack message.
+UNPACK = pickle.loads
+
+
+_Call = namedtuple('_Call', ['funcname', 'args', 'kwargs', 'call_id',
                              'collector_address'])
 _Reply = namedtuple('_Reply', ['method', 'data', 'call_id', 'work_id'])
 
@@ -63,37 +71,21 @@ class Reply(_Reply):
         return make_repr(self, keywords=self._fields, data={'method': M()})
 
 
-PICKLE_MAGIC_KEY = '__pickle__'
-
-
-def default(obj):
-    """The default serializer for MessagePack."""
-    return {PICKLE_MAGIC_KEY: pickle.dumps(obj)}
-
-
-def object_hook(obj):
-    """The object hook for MessagePack."""
-    if PICKLE_MAGIC_KEY in obj:
-        return pickle.loads(obj[PICKLE_MAGIC_KEY])
-    return obj
-
-
-def send(socket, obj, flags=0, topic=None):
+def send(socket, obj, flags=0, topic=None, pack=PACK):
     """Sends a Python object via a ZeroMQ socket. It also can append PUB/SUB
     topic.
     """
-    serial = msgpack.packb(obj, default=default)
     if topic:
-        return socket.send_multipart([topic, serial], flags)
-    else:
-        return socket.send(serial, flags)
+        socket.send(topic, flags | zmq.SNDMORE)
+    message = pack(obj)
+    return socket.send(message, flags)
 
 
-def recv(socket, flags=0):
+def recv(socket, flags=0, unpack=UNPACK):
     """Receives a Python object via a ZeroMQ socket."""
-    serial = socket.recv_multipart(flags)[-1]
+    message = socket.recv_multipart(flags)[-1]
     try:
-        return msgpack.unpackb(serial, object_hook=object_hook)
+        return unpack(message)
     except BaseException as exc:
-        exc.serial = serial
+        exc.message = message
         raise
